# Installation

At the command line:

    $ pip install welly

Or, if you use Conda environments:

    $ conda create -n welly python=3.9
    $ conda activate welly

If you want to help develop Welly, read [Development](development.md).
